@@ -1,7 +1,7 @@
 package Dancer::Plugin::reCAPTCHA;
 # ABSTRACT: Easily integrate reCAPTCHA into your Dancer applications
 {
-    $Dancer::Plugin::reCAPTCHA::VERSION = '0.3';
+    $Dancer::Plugin::reCAPTCHA::VERSION = '0.4';
 }
 
 
@@ -9,7 +9,7 @@ use Dancer ':syntax';
 use Dancer::Plugin;
 use Captcha::reCAPTCHA;
 
-my $rc   = Captcha::reCAPTCHA->new;
+my $rc = Captcha::reCAPTCHA->new;
 
 
 register recaptcha_display => sub {
@@ -18,7 +18,7 @@ register recaptcha_display => sub {
         $conf->{ public_key },
         undef,
         $conf->{ use_ssl },
-        undef,
+        { theme =>  $conf->{ theme }},
     );
 };
 
@@ -50,28 +50,7 @@ Dancer::Plugin::reCAPTCHA - Easily integrate reCAPTCHA into your Dancer applicat
 
 =head1 VERSION
 
-version 0.3
-
-=head1 SYNOPSIS
-
-    use Dancer::Plugin::reCAPTCHA;
-
-    # In your form display....
-    return template 'accounts/create', { 
-        recaptcha => recaptcha_display(),
-    };
-
-    # In your template (TT2)
-    [% recaptcha %]
-
-    # In your validation code....
-    my $challenge = param( 'recaptcha_challenge_field' );
-    my $response  = param( 'recaptcha_response_field' );
-    my $result    = recaptcha_check(
-        $challenge, 
-        $response,
-    );
-    die "User didn't match the CAPTCHA" unless $result->{ is_valid };
+version 0.4
 
 =head1 METHODS
 
@@ -110,6 +89,35 @@ For example:
 
 See L<Captcha::reCAPTCHA> for a description of the result hash.
 
+=head1 SYNOPSIS
+    # In your config.yml
+    plugins:
+      reCAPTCHA:
+        public_key: "public key goes here"
+        private_key: "private key goes here"
+        theme: "clean"
+        use_ssl: 0
+
+    # In your application
+    use Dancer::Plugin::reCAPTCHA;
+
+    # In your form display....
+    return template 'accounts/create', { 
+        recaptcha => recaptcha_display(),
+    };
+
+    # In your template (TT2)
+    [% recaptcha %]
+
+    # In your validation code....
+    my $challenge = param( 'recaptcha_challenge_field' );
+    my $response  = param( 'recaptcha_response_field' );
+    my $result    = recaptcha_check(
+        $challenge, 
+        $response,
+    );
+    die "User didn't match the CAPTCHA" unless $result->{ is_valid };
+
 =head2 TODO
 
 Add a real test suite.
